@@ -2,13 +2,13 @@
 #' @encoding UTF-8
 #'
 #' @title Objects to be used for restricted layout structure Hasse diagram
-#' @description Returns an object of class \code{"rls"} that contains the structural objects of the layout structure. The output can be used in a consecutive function to generate the Hasse diagram of the restricted layout structure of the experimental design.
+#' @description Returns an object of class \code{"rls"} that contains the structural objects of the layout structure. The output can be used in a consecutive function to generate the Hasse diagram of the restricted layout structure of the experimental design. All factors are treated as categorical. 
 #'
-#' @param datadesign A data frame, list or environment (or object coercible by as.data.frame to a data frame) containing the variables/factors 
-#' in the experimental design. The dataframe should only include the variables/factors/columns that the user wants to evaluate in the 
+#' @param datadesign A data frame, list or environment (or object coercible by as.data.frame to a data frame) containing the factors 
+#' in the experimental design. The dataframe should \strong{only} include the factors/columns that the user wants to evaluate in the 
 #' consecutive \code{\link[hassediagrams]{hasserls}} function to generate the Hasse diagram of the restricted layout structure.
 #' @param randomfacsid An optional vector specifying whether the factors are defined as fixed (entry = 0) or random (entry = 1). 
-#' The default choice is \code{NULL} and the function automatically sets all entries to 0. The length of the vector should be equal to the number of variables/factors in the design, i.e., the length of the vector should be equal to the number of columns of the argument \code{datadesign}.
+#' The default choice is \code{NULL} and the function automatically sets all entries to 0. The length of the vector should be equal to the number of factors in the design, i.e., the length of the vector should be equal to the number of columns of the argument \code{datadesign}.
 #'
 #' @return The function returns an object of class \code{"rls"} which is a list with the following components:
 #' 
@@ -88,6 +88,14 @@
 
 itemlist <- function(datadesign, randomfacsid = NULL) {
   
+  old_names <- colnames(datadesign)
+  new_names <- gsub(" ", "_", old_names)
+  
+  if (!identical(old_names, new_names)) {
+    colnames(datadesign) <- new_names
+    warning("Spaces in datadesign column names have been replaced with underscores.")
+  }
+  
   check1 <- apply(datadesign, 2, function(a) length(unique(a))==1)
   
   if(any(check1==TRUE)) {
